#
# spec file for package python-PyYAML
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-PyYAML
Version:        5.4.1
Release:        150300.3.3.1
Summary:        YAML parser and emitter for Python
License:        MIT
URL:            https://github.com/yaml/pyyaml
Source:         https://files.pythonhosted.org/packages/source/P/PyYAML/PyYAML-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  libyaml-devel
BuildRequires:  python-rpm-macros
%ifpython2
# python-yaml was last used in openSUSE 12.1.
Provides:       %{oldpython}-yaml = %{version}
Obsoletes:      %{oldpython}-yaml < %{version}
%endif

%description
YAML is a data serialization format designed for human readability
and interaction with scripting languages. PyYAML is a YAML parser
and emitter for Python.

PyYAML features a complete YAML 1.1 parser, Unicode support, pickle
support, capable extension API, and sensible error messages. PyYAML
supports standard YAML tags and provides Python-specific tags that
allow to represent an arbitrary Python object.

PyYAML is applicable for a broad range of tasks from complex
configuration files to object serialization and persistance.

%python_subpackages

%prep
%setup -q -n PyYAML-%{version}

%build
export CFLAGS="%{optflags}"
%python_build
# Fix example permissions.
find examples/ -type f | xargs chmod a-x

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# Increase file-descriptor-count for ppc to make tests happy.
%ifarch ppc ppc64 s390 s390x
ulimit -Sn 2048
%endif
%python_exec setup.py test

%files %{python_files}
%license LICENSE
%doc CHANGES README examples/
%{python_sitearch}/yaml
%{python_sitearch}/_yaml
%{python_sitearch}/PyYAML-%{version}-py%{python_version}.egg-info

%changelog
* Tue Jun 11 2024 dmueller@suse.com
- reenable the cython yaml loader (bsc#1225641)
* Sun Jan 24 2021 dmueller@suse.com
- update to 5.4.1 (bsc#1174514, CVE-2020-14343):
  * Fix stub compat with older pyyaml versions that may unwittingly load it
  * Build modernization, remove distutils, fix metadata, build wheels, CI to GHA
  * Fix for CVE-2020-14343, moves arbitrary python tags to UnsafeLoader
  * Fix memory leak in implicit resolver setup
  * Fix py2 copy support for timezone objects
  * Fix compatibility with Jython
* Thu Mar 19 2020 mimi.vx@gmail.com
- update to 5.3.1
  * fixes boo#1165439 (cve-2020-1747) Prevents arbitrary code execution
  during python/object/new constructor
* Tue Jan  7 2020 mimi.vx@gmail.com
- update to 5.3
  * Use `is` instead of equality for comparing with `None`
  * fix typos and stylistic nit
  * Fix up small typo
  * Fix handling of __slots__
  * Allow calling add_multi_constructor with None
  * Add use of safe_load() function in README
  * Fix reader for Unicode code points over 0xFFFF
  * Enable certain unicode tests when maxunicode not > 0xffff
  * Use full_load in yaml-highlight example
  * Document that PyYAML is implemented with Cython
  * Fix for Python 3.10
  * increase size of index, line, and column fields
  * remove some unused imports
  * Create timezone-aware datetimes when parsed as such
  * Add tests for timezone
* Tue Dec  3 2019 mimi.vx@gmail.com
- update to 5.2
  * A more flexible fix for custom tag constructors
  * Change default loader for yaml.add_constructor
  * Change default loader for add_implicit_resolver, add_path_resolver
  * Move constructor for object/apply to UnsafeConstructor
  * Fix logic for quoting special characters
* Thu Aug  1 2019 mcalabkova@suse.com
- update to 5.1.2
  * Re-release of 5.1 with regenerated Cython sources to build properly for Python 3.8b2+
* Fri Jun  7 2019 mimi.vx@gmail.com
- update to 5.1.1
  * Re-release of 5.1 with regenerated Cython sources to build properly for Python 3.8
* Thu Mar 14 2019 tchvatal@suse.com
- Update to 5.1:
  * many changes, see CHANGES
  * bsc#1099308 CVE-2017-18342 PyYAML: yaml.load() API could execute arbitrary code
* Mon Jan 14 2019 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Sun Jul 15 2018 mimi.vx@gmail.com
- update to 3.13
  * fix compactibility with python 3.7
* Fri Mar  3 2017 sor.alexei@meowr.ru
- Use pythonhosted.org for the reference link.
- Provide python-yaml instead of python2-yaml again.
* Mon Feb 20 2017 jmatejek@suse.com
- update for multipython build
* Sat Sep  3 2016 mardnh@gmx.de
- Update to 3.12
  - Adding an implicit resolver to a derived loader should not
    affect the base loader (fixes issue #57).
  - Uniform representation for OrderedDict? across different
    versions of Python (fixes issue #61).
  - Fixed comparison to None warning (closes issue #64).
- fix Source URL
* Wed Jul 30 2014 toddrme2178@gmail.com
- Update to 3.11
  - Source and binary distributions are rebuilt against the latest
    versions of Cython and LibYAML.
* Wed Feb  5 2014 ro@suse.de
- increase file-descriptor-count for s390 to make tests happy
* Tue Mar  5 2013 dvaleev@suse.com
- increase file-descriptor-count for ppc to make tests happy
* Thu Jan 10 2013 p.drouand@gmail.com
- Initial python3 support
* Wed Dec 19 2012 saschpe@suse.de
- Build against libyaml to get the faster module
* Tue Jan 31 2012 saschpe@suse.de
- Initial version
